// component/plus/plus.js
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')

Component({
  /**
   * 组件的属性列表
   */
  properties: {
    skuList: {
      type: Array,
      value: [],
    },
    plusBgi:{
      type: Object,
      value: null
    },
    currentHasUserInfo:{
      type: Boolean,
      type: false
    }
  },

  /**
   * 组件的初始数据
   */
  data: {
    currentTab:'999'
  },
  /**
   * 组件的方法列表
   */
  methods: {
    _getUserInfo(res = {}) {
      const userInfo = res.detail || {}
      console.log('userInfo',userInfo)
      // 先授权再领卡
      if (res.detail.userInfo) {
        utils.getUserInfoByBtn(userInfo).then( (data = {} ) => {
          const {token} = data
          wx.setStorageSync('_accreditUserInfo', userInfo)
          wx.hideNavigationBarLoading()
          if (token) {
            wx.setStorageSync('token', token)
          } else {
            wx.setStorageSync('token', '')
          }
          wx.setStorageSync('_baseUserInfo', data) // 缓存用户信息
          this.setUserInfo()   // 判断有无开卡
        }).catch(err=> {
          if (err) {
            wx.showToast({
              title: `会员系统异常请稍后重试!`,
              icon: 'none'
            })
          }
        })
      }
    },
    setUserInfo () {
      const userInfo = wx.getStorageSync('_baseUserInfo')
      // 新用户去激活领卡 
      if (userInfo && userInfo.member && !userInfo.member.mobile) {
        wxService.openCard()
        return false
      }
      // 跳转
      const urls = getCurrentPages()
      setTimeout(() => {
        const item = urls[0].options
        if (item.route) {
          try {
            const options = JSON.parse(item.options)
            wxService.router(`/${item.route}`).search(options).replace()
          } catch (e) {
            wxService.router('/pages/userCenter/userCenter').replace()
          }
        } else {
          wxService.router('/pages/userCenter/userCenter').replace()
        }
      }, 200)
    },
    switchNav(e){
      this.setData({
        currentTab: e.currentTarget.dataset.current,
        id: e.currentTarget.dataset.id
      })
    },
    payPlus() {
      if (!this.data.id){
        wx.showToast({
          title: '请先选择会员卡',
          icon: 'none',
          mask: true
        })
        return
      }
      // 下单
      wx.showLoading({
        title: '加载中'
      })
      // 获取支付参数
      wxService.post(`/sale/payment/premium/buyer/preorder/wxa`, {
        premiumId: this.data.id
      }).then(res => {
        if (!res) return false;
        const { result, data } = res && res.data || res && res.result
        if (result == 0) {
          console.log('data', data)
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // wx.showToast({
              //   title: '支付成功',
              //   icon: 'none',
              //   mask: true
              // })
              // 支付成功页面
              console.log(res)
              wxService.router('/subPackage/page/pages/paymentStatus/paymentStatus')
            },
            fail(res) {
              wx.hideLoading()
              wx.showToast({
                title: '支付失败',
                icon: 'none',
                mask: true
              })
            }
          }, data))
        }
      })
    },
    
  }
})
